@@ -3,9 +3,9 @@
 # package ::_interconnected_map {{{
 package Games::RolePlay::MapGen::_disallow_autoviv;
 
-use strict;
+use common::sense;
 use Tie::Array;
-use base 'Tie::StdArray';
+use parent -norequire => 'Tie::StdArray';
 use Carp;
 
 1;
@@ -30,7 +30,7 @@ sub FETCH {
 
 package Games::RolePlay::MapGen::_interconnected_map;
 
-use strict;
+use common::sense;
 use Carp;
 
 1;
@@ -77,6 +77,7 @@ sub interconnect_map {
 sub disconnect_map {
     my $map = shift;
 
+    local $@;
 
     eval {
         untie @$_ for grep {tied $_} @$map;
@@ -140,7 +141,7 @@ sub DESTROY {
 # package ::_group; {{{
 package Games::RolePlay::MapGen::_group;
 
-use strict;
+use common::sense;
 
 1;
 
@@ -300,7 +301,7 @@ sub enumerate_extents {
 # package ::_tile; {{{
 package Games::RolePlay::MapGen::_tile;
 
-use strict;
+use common::sense;
 
 1;
 
@@ -323,7 +324,7 @@ sub DESTROY { warn "tile verbosely dying" if $ENV{VERBOSE_TILE_DEATH} }  # searc
 # package ::_door; {{{
 package Games::RolePlay::MapGen::_door;
 
-use strict;
+use common::sense;
 
 1;
 
@@ -344,9 +345,9 @@ sub new {
 
 package Games::RolePlay::MapGen::Tools;
 
-use strict;
+use common::sense;
 use Carp;
-use base q(Exporter);
+use parent q(Exporter);
 
 our @EXPORT_OK = qw(choice roll random irange range str_eval _group _tile _door);
 
